--[[
GridStatusSelf.lua
Add grid indicator for Self

Authors: mbf
--]]

-- Libraries
local L = AceLibrary("AceLocale-2.2"):new("GridStatusSelf")

local GridStatusSelf = Grid:GetModule("GridStatus"):NewModule("GridStatusSelf")
GridStatusSelf.menuName = L["Self Flags"]

-- Defaults
GridStatusSelf.defaultDB = {
	alert_self = {
		text = L["Self"],
		enable = true,
		color = { r = 0.25, g = 1.0, b = 0.25, a = 1 },
		priority = 75,
		range = false,
		icon = false,
	},
}

-- Mod init
function GridStatusSelf:OnInitialize()
	self.super.OnInitialize(self)
	self:Debug("OnInitialize")

	self:RegisterStatus("alert_self", L["Self: Me"])
end

-- Mod enable
function GridStatusSelf:OnEnable()
	self:Debug("OnEnable")

	self:RegisterEvent("Grid_RosterUpdated")

	self:Update()
end

function GridStatusSelf:OnDisable()
	self:Debug("OnDisable")

	self:UnregisterEvent("Grid_RosterUpdated")

	self:ClearAll("alert_self")
end

-- Reset
function GridStatusSelf:Reset()
	self.super.Reset(self)
	self:OnDisable()
	self:OnEnable()
end

function GridStatusSelf:Grid_RosterUpdated(guid, unitid)
	self:Update()
end

function GridStatusSelf:Update()
	self:Debug("Update")

	self:ClearAll("alert_self")
    local party_self = UnitGUID("player")
	local settings_self = self.db.profile.alert_self
    self.core:SendStatusGained(party_self, "alert_self",
                               settings_self.priority,
                               settings_self.range,
                               settings_self.color,
                               settings_self.text,
                               nil, nil,
                               settings_self.icon)
end

function GridStatusSelf:ClearAll(status)
	for name in self.core:CachedStatusIterator(status) do
		self.core:SendStatusLost(name, status)
	end
end
